/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * AtomIdDescriptor.cpp
 *
 *  Created on: Feb 5, 2010
 *      Author: crueger
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "AtomIdDescriptor.hpp"
#include "AtomIdDescriptor_impl.hpp"

#include "Atom/atom.hpp"
#include "CodePatterns/Observer/ObservedContainer_impl.hpp"

using namespace std;


AtomIdDescriptor_impl::AtomIdDescriptor_impl(atomId_t _id) :
  id(_id)
{}

AtomIdDescriptor_impl::~AtomIdDescriptor_impl()
{}

bool AtomIdDescriptor_impl::predicate(std::pair<atomId_t,atom*> atom) {
  return atom.first==id;
}

AtomDescriptor AtomById(atomId_t id){
  return AtomDescriptor(AtomDescriptor::impl_ptr(new AtomIdDescriptor_impl(id)));
}

atom *AtomIdDescriptor_impl::find(){
  World::AtomSet &atoms = getAtoms();
  World::AtomSet::const_iterator res = atoms.find(id);
  return (res!=atoms.end())?((*res).second):0;
}

vector<atom*> AtomIdDescriptor_impl::findAll(){
  atom *res = find();
  return (res)?(vector<atom*>(1,res)):(vector<atom*>());
}
